@@ -3,6 +3,8 @@
 #![feature(proc_macro_diagnostic)]
 
 //! **I do not recommend using this directly, please sea [rust-ad](https://crates.io/crates/rust-ad).**
+//!
+//! External proc-macro functionality.
 
 use rust_ad_core::traits::*;
 use rust_ad_core::*;
@@ -56,12 +58,15 @@ pub fn forward(_item: TokenStream) -> TokenStream {
             }
         })
         .collect::<Vec<String>>();
-    let input_deriatives = "1f32,".repeat(inputs.len());
+    let input_derivatives = "1f32,".repeat(inputs.len());
     let inputs_str = inputs.into_iter().collect::<String>();
 
     let call_str = format!(
         "{}{}({}{})",
-        FORWARD_MODE_PREFIX, function_ident, inputs_str, input_deriatives
+        rust_ad_consts::FORWARD_PREFIX,
+        function_ident,
+        inputs_str,
+        input_derivatives
     );
     call_str.parse().unwrap()
 }
@@ -104,7 +109,12 @@ pub fn reverse(_item: TokenStream) -> TokenStream {
         })
         .collect::<String>();
 
-    let call_str = format!("{}{}({}1f32)", REVERSE_MODE_PREFIX, function_ident, inputs);
+    let call_str = format!(
+        "{}{}({}1f32)",
+        rust_ad_consts::REVERSE_PREFIX,
+        function_ident,
+        inputs
+    );
     call_str.parse().unwrap()
 }
 
@@ -186,7 +196,11 @@ pub fn forward_autodiff(_attr: TokenStream, item: TokenStream) -> TokenStream {
     // ---------------------------------------------------------------------------
     // Updates identifier
     function.sig.ident = syn::Ident::new(
-        &format!("{}{}", FORWARD_MODE_PREFIX, function.sig.ident.to_string()),
+        &format!(
+            "{}{}",
+            rust_ad_consts::FORWARD_PREFIX,
+            function.sig.ident.to_string()
+        ),
         function.sig.ident.span(),
     );
     // Appends derivative inputs to function signature, `f(x,y)` -> `f(x,y,dx,dy)`
@@ -196,7 +210,7 @@ pub fn forward_autodiff(_attr: TokenStream, item: TokenStream) -> TokenStream {
         .iter()
         .map(|fn_arg| {
             // eprintln!("fn_arg:\n{:#?}",fn_arg);
-            let typed = fn_arg.typed().expect("forward: signatre input not typed");
+            let typed = fn_arg.typed().expect("forward: signature input not typed");
             let val_type = typed
                 .ty
                 .path()
@@ -263,8 +277,8 @@ pub fn forward_autodiff(_attr: TokenStream, item: TokenStream) -> TokenStream {
         Err(_) => return start_item,
     };
 
-    // Intersperses forward deriatives
-    let derivative_stmts_res = interspese_succedding_stmts(
+    // Intersperses forward derivatives
+    let derivative_stmts_res = intersperse_succeeding_stmts(
         function.block.stmts,
         (&type_map, function_inputs.as_slice()),
         forward_derivative,
@@ -408,20 +422,12 @@ pub fn reverse_autodiff(_attr: TokenStream, item: TokenStream) -> TokenStream {
             reverse_stmts.push(der);
         }
     }
+    // eprintln!("component_map: {:?}", component_map);
     reverse_stmts.push(reverse_accumulate_inputs(
         &function_inputs,
         &component_map,
         &type_map,
     ));
-    // let mut reverse_stmts = function
-    //     .block
-    //     .stmts
-    //     .iter()
-    //     .rev()
-    //     .filter_map(|s| reverse_derivative(s, &type_map, &mut component_map))
-    //     .collect::<Vec<_>>();
-
-    // eprintln!("component_map: {:?}", component_map);
 
     function.block.stmts.append(&mut reverse_stmts);
     // Appends return statement after adding reverse code.
@@ -430,7 +436,11 @@ pub fn reverse_autodiff(_attr: TokenStream, item: TokenStream) -> TokenStream {
     // Updates function identifier
     // ---------------------------------------------------------------------------
     function.sig.ident = syn::Ident::new(
-        &format!("{}{}", REVERSE_MODE_PREFIX, function.sig.ident.to_string()),
+        &format!(
+            "{}{}",
+            rust_ad_consts::REVERSE_PREFIX,
+            function.sig.ident.to_string()
+        ),
         function.sig.ident.span(),
     );
 
@@ -439,7 +449,7 @@ pub fn reverse_autodiff(_attr: TokenStream, item: TokenStream) -> TokenStream {
     join_streams(start_item, new_stream)
 }
 
-/// Unwraps nested expressions into seperate variable assignments.
+/// Unwraps nested expressions into separate variable assignments.
 ///
 /// E.g.
 /// ```ignore
@@ -566,7 +576,7 @@ fn unwrap_statement(stmt: &syn::Stmt) -> Vec<syn::Stmt> {
                             .local_mut()
                             .expect("unwrap: function statement not local");
                         let func_ident =
-                            format!("{}_{}", FUNCTION_PREFFIX.repeat(i + 1), local_ident);
+                            format!("{}_{}", FUNCTION_PREFIX.repeat(i + 1), local_ident);
                         func_local
                             .pat
                             .ident_mut()
@@ -580,7 +590,7 @@ fn unwrap_statement(stmt: &syn::Stmt) -> Vec<syn::Stmt> {
 
                         // Updates statement to contain reference to new variables
                         let arg_expr: syn::Expr =
-                            syn::parse_str(&func_ident).expect("unwrap: funtion parse fail");
+                            syn::parse_str(&func_ident).expect("unwrap: function parse fail");
                         base_statement
                             .local_mut()
                             .expect("unwrap: function local")
@@ -601,26 +611,26 @@ fn unwrap_statement(stmt: &syn::Stmt) -> Vec<syn::Stmt> {
                     // If method is called on value which is binary expression (e.g. `(x+y).method()`).
                     if let syn::Expr::Binary(bin_expr) = &*parenthesis.expr {
                         // Creates new statement.
-                        let mut reciver_stmt = stmt.clone();
-                        let reciver_local = reciver_stmt
+                        let mut receiver_stmt = stmt.clone();
+                        let receiver_local = receiver_stmt
                             .local_mut()
                             .expect("unwrap: receiver statement not local");
-                        let reciver_ident =
+                        let receiver_ident =
                             format!("{}_{}", RECEIVER_PREFIX, local_ident.to_string());
-                        reciver_local
+                        receiver_local
                             .pat
                             .ident_mut()
                             .expect("unwrap: receiver not ident")
-                            .ident = syn::parse_str(&reciver_ident)
+                            .ident = syn::parse_str(&receiver_ident)
                             .expect("unwrap: receiver ident parse fail");
-                        *reciver_local.init.as_mut().unwrap().1 =
+                        *receiver_local.init.as_mut().unwrap().1 =
                             syn::Expr::Binary(bin_expr.clone());
                         // Recurse
-                        statements.append(&mut unwrap_statement(&reciver_stmt));
+                        statements.append(&mut unwrap_statement(&receiver_stmt));
 
                         // Updates statement to contain variable referencing new statement.
                         let receiver_expr: syn::Expr =
-                            syn::parse_str(&reciver_ident).expect("unwrap: receiver parse fail");
+                            syn::parse_str(&receiver_ident).expect("unwrap: receiver parse fail");
                         *base_statement
                             .local_mut()
                             .expect("unwrap: 3a")
@@ -646,7 +656,7 @@ fn unwrap_statement(stmt: &syn::Stmt) -> Vec<syn::Stmt> {
                             .local_mut()
                             .expect("unwrap: method statement not local");
                         let func_ident =
-                            format!("{}_{}", FUNCTION_PREFFIX.repeat(i + 1), local_ident);
+                            format!("{}_{}", FUNCTION_PREFIX.repeat(i + 1), local_ident);
                         func_local
                             .pat
                             .ident_mut()
